@@ -9,25 +9,25 @@ import io
 import os
 
 
-SEEK_SET = getattr(io, 'SEEK_SET', 0)
-SEEK_CUR = getattr(io, 'SEEK_CUR', 1)
-SEEK_END = getattr(io, 'SEEK_END', 2)
+SEEK_SET = getattr(io, u'SEEK_SET', 0)
+SEEK_CUR = getattr(io, u'SEEK_CUR', 1)
+SEEK_END = getattr(io, u'SEEK_END', 2)
 
 
 class FileChunkIO(io.FileIO):
-    """
+    u"""
     A class that allows you reading only a chunk of a file.
     """
-    def __init__(self, name, mode='r', closefd=True, offset=0, bytes=None,
+    def __init__(self, name, mode=u'r', closefd=True, offset=0, bytes=None,
                  *args, **kwargs):
-        """
+        u"""
         Open a file chunk. The mode can only be 'r' for reading. Offset
         is the amount of bytes that the chunks starts after the real file's
         first byte. Bytes defines the amount of bytes the chunk has, which you
         can set to None to include the last byte of the real file.
         """
-        if not mode.startswith('r'):
-            raise ValueError("Mode string must begin with 'r'")
+        if not mode.startswith(u'r'):
+            raise ValueError(u"Mode string must begin with 'r'")
         self.offset = offset
         self.bytes = bytes
         if bytes is None:
@@ -36,7 +36,7 @@ class FileChunkIO(io.FileIO):
         self.seek(0)
 
     def seek(self, offset, whence=SEEK_SET):
-        """
+        u"""
         Move to a new chunk position.
         """
         if whence == SEEK_SET:
@@ -47,13 +47,13 @@ class FileChunkIO(io.FileIO):
             self.seek(self.bytes + offset)
 
     def tell(self):
-        """
+        u"""
         Current file position.
         """
         return super(FileChunkIO, self).tell() - self.offset
 
     def read(self, n=-1):
-        """
+        u"""
         Read and return at most n bytes.
         """
         if n >= 0:
@@ -64,13 +64,13 @@ class FileChunkIO(io.FileIO):
             return self.readall()
 
     def readall(self):
-        """
+        u"""
         Read all data from the chunk.
         """
         return self.read(self.bytes - self.tell())
 
     def readinto(self, b):
-        """
+        u"""
         Same as RawIOBase.readinto().
         """
         data = self.read(len(b))
