@@ -19,7 +19,7 @@
 # along with duplicity; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-"""Store global configuration information"""
+u"""Store global configuration information"""
 
 import os
 import sys
@@ -27,19 +27,19 @@ import socket
 
 
 # The current version of duplicity
-version = "0.7.17"
+version = u"0.8.09"
 
 # Prefix for all files (appended before type-specific prefixes)
-file_prefix = ""
+file_prefix = b""
 
 # Prefix for manifest files only
-file_prefix_manifest = ""
+file_prefix_manifest = b""
 
 # Prefix for archive files only
-file_prefix_archive = ""
+file_prefix_archive = b""
 
 # Prefix for sig files only
-file_prefix_signature = ""
+file_prefix_signature = b""
 
 # The name of the current host, or None if it cannot be set
 hostname = socket.getfqdn()
@@ -58,12 +58,13 @@ current_time = None
 # contains the signatures and manifests of the relevent backup
 # collection), and for checkpoint state between volumes.
 # NOTE: this gets expanded in duplicity.commandline
-os.environ["XDG_CACHE_HOME"] = os.getenv("XDG_CACHE_HOME", os.path.expanduser("~/.cache"))
-archive_dir = os.path.expandvars("$XDG_CACHE_HOME/duplicity")
+os.environ[u"XDG_CACHE_HOME"] = os.getenv(u"XDG_CACHE_HOME", os.path.expanduser(u"~/.cache"))
+archive_dir = os.path.expandvars(u"$XDG_CACHE_HOME/duplicity")
+archive_dir_path = None
 
 # config dir for future use
-os.environ["XDG_CONFIG_HOME"] = os.getenv("XDG_CONFIG_HOME", os.path.expanduser("~/.config"))
-config_dir = os.path.expandvars("$XDG_CONFIG_HOME/duplicity")
+os.environ[u"XDG_CONFIG_HOME"] = os.getenv(u"XDG_CONFIG_HOME", os.path.expanduser(u"~/.config"))
+config_dir = os.path.expandvars(u"$XDG_CONFIG_HOME/duplicity")
 
 # Restores will try to bring back the state as of the following time.
 # If it is None, default to current time.
@@ -87,7 +88,7 @@ gpg_binary = None
 gpg_profile = None
 
 # Options to pass to gpg
-gpg_options = ''
+gpg_options = u''
 
 # Maximum file blocksize
 max_blocksize = 2048
@@ -105,10 +106,10 @@ pydevd = False
 # Character used like the ":" in time strings like
 # 2002-08-06T04:22:00-07:00.  The colon isn't good for filenames on
 # windows machines.
-time_separator = ":"
+time_separator = u":"
 
 # Global lockfile used to manage concurrency
-lockpath = ""
+lockpath = u""
 lockfile = None
 
 # If this is true, only warn and don't raise fatal error when backup
@@ -165,10 +166,10 @@ temproot = None
 timeout = 30
 
 # FTP data connection type
-ftp_connection = 'passive'
+ftp_connection = u'passive'
 
 # Protocol for webdav
-webdav_proto = 'http'
+webdav_proto = u'http'
 
 # Asynchronous put/get concurrency limit
 # (default of 0 disables asynchronicity).
@@ -196,6 +197,15 @@ s3_use_rrs = False
 # Whether to use S3 Infrequent Access Storage
 s3_use_ia = False
 
+# Whether to use S3 Glacier Storage
+s3_use_glacier = False
+
+# Whether to use S3 Glacier Deep Archive Storage
+s3_use_deep_archive = False
+
+# Whether to use S3 One Zone Infrequent Access Storage
+s3_use_onezone_ia = False
+
 # True if we should use boto multiprocessing version
 s3_use_multiprocessing = False
 
@@ -216,6 +226,26 @@ s3_multipart_max_timeout = None
 # Use server side encryption in s3
 s3_use_sse = False
 
+# Use server side kms encryption in s3
+s3_use_sse_kms = False
+s3_kms_key_id = None
+s3_kms_grant = None
+
+# Which storage policy to use for Swift containers
+swift_storage_policy = u""
+
+# The largest size upload supported in a single put call for azure
+azure_max_single_put_size = None
+
+# The size of the blocks put to azure blob storage if bigger than azure_max_single_put_size
+azure_max_block_size = None
+
+# Maximum number of parallel connections to use when the blob size for azure exceeds 64MB
+azure_max_connections = None
+
+# Standard storage tier used for storring backup blobs (Hot|Cool|Archive).
+azure_blob_tier = None
+
 # Whether to use the full email address as the user name when
 # logging into an imap server. If false just the user name
 # part of the email address is used.
@@ -223,7 +253,10 @@ imap_full_address = False
 
 # Name of the imap folder where we want to store backups.
 # Can be changed with a command line argument.
-imap_mailbox = "INBOX"
+imap_mailbox = u"INBOX"
+
+# Sync partial metadata by default
+metadata_sync_mode = u"partial"
 
 # Whether the old filename format is in effect.
 old_filenames = False
@@ -239,10 +272,10 @@ sftp_command = None
 ssh_askpass = False
 
 # user added ssh options
-ssh_options = ""
+ssh_options = u""
 
 # default cf backend is pyrax
-cf_backend = "pyrax"
+cf_backend = u"pyrax"
 
 # HTTPS ssl options (currently only webdav, lftp)
 ssl_cacert_file = None
@@ -250,7 +283,7 @@ ssl_cacert_path = None
 ssl_no_check_certificate = False
 
 # user added rsync options
-rsync_options = ""
+rsync_options = u""
 
 # will be a Restart object if restarting
 restart = None
@@ -292,11 +325,14 @@ progress_rate = 3
 par2_redundancy = 10
 
 # Verbatim par2 other options
-par2_options = ""
+par2_options = u""
 
 # Whether to enable gio backend
 use_gio = False
 
+# If set, collect only the file status, not the whole root.
+file_changed = None
+
 # delay (in seconds) before next operation after failure
 backend_retry_delay = 30
 
@@ -305,4 +341,4 @@ backend_retry_delay = 30
 # 'utf-8' or some other sane encoding, but will sometimes fail and return
 # either 'ascii' or None.  Both are bogus, so default to 'utf-8' if it does.
 fsencoding = sys.getfilesystemencoding()
-fsencoding = fsencoding if fsencoding not in ['ascii', None] else 'utf-8'
+fsencoding = fsencoding if fsencoding not in [u'ascii', u'ANSI_X3.4-1968', None] else u'utf-8'
